#ifndef __NWLOCALE_H__
/*----------------------------------------------------------------------------*
 *                                                                            *
 *      This include file defines the constants, types, structures,           *
 *      and prototypes for the Novell Enabling APIs.                          *
 *                                                                            *
 *      (c) Copyright. 1989-1991 Novell, Inc.  All rights reserved.           *
 *                                                                            *
 *----------------------------------------------------------------------------*/

#ifndef NWAPI
#define NWAPI far pascal
#endif

#if defined(MEDIUM_MODEL)
#undef NWFAR
#define NWFAR
#endif

#ifndef NWFAR
#define NWFAR far
#endif

#ifndef NWCCODE
#define NWCCODE           unsigned int
#endif

#define NUMBER_TYPE long double

#if !defined (_SIZE_T_DEFINED) && !defined (_SIZE_T) 
typedef unsigned int size_t;
#define _SIZE_T
#endif

/* (in imitation of stdlib.h) */

#define L_MB_LEN_MAX       2   /* (in imitation of limits.h) */
#define MERIDLEN           5
#define NWSINGLE_BYTE      1
#define NWDOUBLE_BYTE      2

#define _UCHAR             (unsigned char)

#define LC_ALL             0
#define LC_COLLATE         1
#define LC_CTYPE           2
#define LC_MONETARY        3
#define LC_NUMERIC         4
#define LC_TIME            5


/*============================================================================
   typedef Llconv
============================================================================*/
typedef struct Llconv
   {
   char decimal_point[4];                     /* non-monetary decimal point */
   char thousands_sep[4];   /* non-monetary separator for digits left of the
                               decimal-point */
   char grouping[4];           /* String indicating size of groups of digits*/
   /*
    The international currency symbol applicable to the current locale.
    The first three characters contain the alphabetic international currency
    symbol in accordance with those specified in ISO 4217 "codes for the
    representation of currency and funds." The fourth character is the
    character used to separate the international currency symbol from the
    monetary quantity.
   */
   char int_curr_symbol[8];
   char currency_symbol[4];       /* Currency symbol for the current locale.*/
   char mon_decimal_point[4];                     /* monetary decimal point */
   char mon_thousands_sep[4];     /* monetary separator for digits left of the
                                     decimal-point */
   char mon_grouping[8];       /* String indicating size of groups of digits*/
   char positive_sign[4];        /* Sign indicating positive monetary value */
   char negative_sign[4];        /* Sign indicating negative monetary value */
   char int_frac_digits;     /* Num of fractional digits in monetary display*/
   char frac_digits;     /* Num of fractional digits in non-monetary display*/
   char p_cs_precedes;      /* 1=precede or 0=succeeds (pos currency symbol)*/
   char p_sep_by_space;    /* 1=space sep or 0=no space sep (currency symbol*/
   char n_cs_precedes; /* location of currency_symbol for neg monetary quant*/
   char n_sep_by_space;  /* separation of currency sym in neg monetary quant*/
   char p_sign_posn;         /* value indicating position of positive_sign for
                                 nonnegative monetary quantity.*/
   char n_sign_posn;         /* value indicating position of negative_sign for
                                negative formatted monetary quantity.*/
   /* Novell Additions to the ANSI definition:*/
   int  code_page;
   int  country_id;
   char data_list_separator[2];
   char date_separator[2];
   char time_separator[2];
   char time_format;
   int date_format;
   char reserved[50];
} LCONV;

/*============================================================================
   function prototypes
============================================================================*/
#if defined(__cplusplus)
extern "C" {
#endif

LCONV NWPTR  NWAPI NWLlocaleconv(LCONV NWPTR lconvPtr);

int NWAPI NWLmblen(
         char NWPTR string,
         size_t maxBytes);

char  NWPTR  NWAPI NWLsetlocale(
         int category,
         const char NWPTR locale);

char  NWPTR  NWAPI NWLstrchr(
         char NWPTR string,
         int find);

/* NWLstrcoll  (see below) */

size_t NWAPI NWLstrcspn(
         const char NWPTR string1,
         const char NWPTR string2);

#ifndef NWL_EXCLUDE_TIME
size_t NWAPI NWLstrftime(
         char NWPTR string,
         size_t maxSize,
         char NWPTR format,
         struct tm NWPTR timePtr);
#endif

char  NWPTR  NWAPI NWLstrpbrk(
         char NWPTR string1,
         const char NWPTR string2);

char  NWPTR  NWAPI NWLstrrchr(
         char NWPTR string,
         int find);

char  NWPTR  NWAPI NWLstrrev(
         char NWPTR string1,
         char NWPTR string2);

size_t NWAPI NWLstrspn(
         const char NWPTR string1,
         const char NWPTR string2);

char  NWPTR  NWAPI NWLstrstr(
         char NWPTR string,
         char NWPTR searchString);

/* NWLstrupr ( see below )*/

size_t NWAPI NWLstrxfrm(
         char NWPTR string1,
         char NWPTR string2,
         size_t numBytes);

char  NWPTR  NWAPI NWIncrement(
         char NWPTR string,
         size_t numChars);

char  NWPTR  NWAPI NWstrImoney(
         char NWPTR buffer,
         NUMBER_TYPE Value);

char  NWPTR  NWAPI NWstrmoney(
         char NWPTR buffer,
         NUMBER_TYPE Value);

int   NWAPI NWstrncoll(
         char NWPTR string1,
         char NWPTR string2,
         size_t maxBytes);

char   NWPTR  NWAPI NWstrncpy(
         char NWPTR target_string,
         char NWPTR source_string,
         int numBytes);

char  NWPTR  NWAPI NWstrnum(
         char NWPTR buffer,
         NUMBER_TYPE Value);

int NWFAR cdecl NWprintf(
         char NWPTR format,
         ...);

#ifndef NWL_EXCLUDE_FILE
int NWFAR cdecl NWfprintf(
         FILE NWPTR stream,
         char NWPTR format,
         ...);
#endif

int NWFAR cdecl NWsprintf(
         char NWPTR buffer,
         char NWPTR format,
         ...);

int NWAPI NWvprintf(
         char NWPTR format,
         char NWPTR arglist);

#ifndef NWL_EXCLUDE_FILE
int NWAPI NWvfprintf(
         FILE NWPTR stream,
         char NWPTR format,
         char NWPTR arglist);
#endif

int NWAPI NWvsprintf(
         char NWPTR buffer,
         char NWPTR format,
         char NWPTR arglist);

int NWFAR cdecl NWwsprintf(
         char NWPTR buffer,
         char NWPTR format,
         ...);

int NWAPI NWatoi(
         char NWPTR string);

int NWAPI NWisalpha(
         unsigned int ch);

int NWAPI NWisalnum(
         unsigned int ch);

int NWAPI NWisdigit(
         unsigned int ch);

void NWAPI NWGetNWLOCALEVersion(unsigned char NWPTR majorVersion,
                                unsigned char NWPTR minorVersion,
                                unsigned char NWPTR revisionLevel,
                                unsigned char NWPTR betaReleaseLevel);

NWCCODE NWAPI NWGetShortMachineName(char NWPTR shortMachineName);


/*============================================================================
   macros
============================================================================*/
#if defined (NWWIN)
#define NWNextChar(s)         AnsiNext(s)
#define NWPrevChar(t, s)      AnsiPrev(t, s)
#define NWLstrupr(s)          AnsiUpper(s)
#define NWLstrcoll(s1, s2)    lstrcmp(s1, s2)

/* AnsiUpper handles double byte characters. */

#define NWCharUpr(c) \
   (int) ( LOWORD ( (DWORD) AnsiUpper ( (LPSTR) (DWORD) c ) ) )

#else

char  NWPTR  NWAPI NWNextChar(
         char NWPTR string);

char  NWPTR  NWAPI NWPrevChar(
         const char NWPTR string,
         char NWPTR position);

char  NWPTR  NWAPI NWLstrupr ( char NWPTR string );
int  NWAPI NWCharUpr ( int chr );
int  NWAPI  NWLstrcoll( char NWPTR string1, char NWPTR string2);
#endif

#define _NWIncrement(s,x) ((_DBCSVector[0].lowValue == 0) \
             ? (s + x) : NWIncrement(s,x))

int  NWAPI NWCharType(unsigned int ch);
int  NWAPI NWCharVal(char NWPTR );

#if defined(__cplusplus)
}
#endif

#define __NWLOCALE_H__
#endif

