/*      (c) COPYRIGHT 1988-1990 by Novell, Inc.  All Rights Reserved.   */
#ifndef _NXT_H
#define _NXT_H
  /*__________________________________________________________________________
       Definitions and structures  for the Netware API Communications logic
    _________________________________________________________________________*/

#include <nwcaldef.h>

  /* assigned socket types */

  #define SOC_DIAGNOSTICS
  #define SHORT_LIVED        0x00
  #define LONG_LIVED         0xFF
  #define ENABLE_WATCHDOG    0xFF
  #define DISABLE_WATCHDOG   0x00

  typedef struct IPXAddress
   {
      BYTE    network[4];                    /* high-low */
      BYTE    node[6];                       /* high-low */
      BYTE    socket[2];                     /* high-low */
   }IPXAddress;


  typedef struct IPXHeader
   {
      WORD        checkSum;                  /* high-low */
      WORD        length;                    /* high-low */
      BYTE        transportControl;
      BYTE        packetType;
      IPXAddress  destination;
      IPXAddress  source;
   }IPXHeader;


  typedef struct SPXHeader
   {
      WORD        checksum;               /* high-low 1's complement */
      WORD        length;                 /* high-low unsigned int */
      BYTE        transportControl;
      BYTE        packetType;
      IPXAddress  destination;
      IPXAddress  source;
      BYTE        connectionControl;      /* bit flags */
      BYTE        dataStreamType;
      WORD        sourceConnectionID;     /* high-low unsigned */
      WORD        destConnectionID;       /* high-low unsigned */
      WORD        sequenceNumber;         /* high-low unsigned */
      WORD        acknowledgeNumber;      /* high-low unsigned */
      WORD        allocationNumber;       /* high-low unsigned */
   }SPXHeader;

   typedef struct CONNECTION_INFO
   {
      BYTE    connectionState;
      BYTE    connectionFlags;
      WORD    sourceConnectionID;               /* hi-lo */
      WORD    destinationConnectionID;          /* hi-lo */
      WORD    sequenceNumber;                   /* hi-lo */
      WORD    acknowledgeNumber;                /* hi-lo */
      WORD    allocationNumber;                 /* hi-lo */
      WORD    remoteAcknowledgeNumber;          /* hi-lo */
      WORD    remoteAllocationNumber;           /* hi-lo */
      WORD    connectionSocket;                 /* hi-lo */
      BYTE    immediateAddress[6];
      IPXAddress   destination;
      WORD    retransmissionCount;              /* hi-lo */
      WORD    estimatedRoundTripDelay;          /* hi-lo */
      WORD    retransmittedPackets;             /* hi-lo */
      WORD    suppressedPackets;                /* hi-lo */
   } CONNECTION_INFO;


#ifndef ECB_STRUCTURES_DEFINED
#define ECB_STRUCTURES_DEFINED

    typedef struct ECBFragment
     {
        void NWPTR address;
        WORD    size;                       /* low-high */
     }ECBFragment;

    typedef struct ECB
     {
        void NWPTR linkAddress;
        void (NWPTR ESRAddress)();
        BYTE        inUseFlag;
        BYTE        completionCode;
        WORD        socketNumber;                   /* high-low */
        BYTE        IPXWorkspace[4];                /* N/A */
        BYTE        driverWorkspace[12];            /* N/A */
        BYTE        immediateAddress[6];            /* high-low */
        WORD        fragmentCount;                  /* low-high */
        ECBFragment fragmentDescriptor[2];
     }ECB;
  #endif /* ECB_STRUCTURES_DEFINED */



  #define SPX_IS_INSTALLED            0xFF
  #define SPX_NOT_INSTALLED           0x00
  #define SPX_CONNECTION_OK           0x00
  #define SPX_CONNECTION_STARTED      0x00
  #define SPX_CONNECTION_ESTABLISHED  0x00
  #define SPX_PACKET_SUCCESSFUL       0x00
  #define SPX_SOCKET_NOT_OPENED       0xFF
  #define SPX_MALFORMED_PACKET        0xFD
  #define SPX_PACKET_OVERFLOW         0xFD
  #define SPX_LISTEN_CANCELED         0xFC
  #define SPX_CONNECTION_TABLE_FULL   0xEF
  #define SPX_INVALID_CONNECTION      0xEE
  #define SPX_NO_ANSWER_FROM_TARGET   0xED
  #define SPX_CONNECTION_FAILED       0xED
  #define SPX_CONNECTION_TERMINATED   0xED
  #define SPX_TERMINATED_POORLY       0xEC


#ifdef __cplusplus
   extern "C" {
#endif /* __cplusplus */

   extern int  NWAPI IPXCancelEvent(ECB NWPTR eventControlBlock);

   extern void NWAPI IPXCloseSocket(WORD socketNumber);

   extern void NWAPI IPXDisconnectFromTarget(BYTE NWPTR networkAddress);

   extern void NWAPI IPXGetInternetworkAddress(BYTE NWPTR networkAddress);

   extern WORD NWAPI IPXGetIntervalMarker(void);

   extern int  NWAPI IPXGetLocalTarget(BYTE NWPTR networkAddress,
                                       BYTE NWPTR immediateAddress,
                                       int NWPTR transportTime);

   extern WORD NWAPI IPXGetMaxPacketSize(void);

   extern BYTE NWAPI IPXInitialize(void);

   extern void NWAPI IPXListenForPacket(ECB NWPTR eventControlBlock);

   extern int  NWAPI IPXOpenSocket(BYTE NWPTR socketNumber,
                                   BYTE socketType);

   /* internal procedure */
   extern int  NWAPI _IPXPacket(ECB NWPTR eventControlBlock,
                                WORD functionNumber);

   /* internal procedure */
   extern void NWAPI _IPXrequest(WORD timeDelay,
                                 ECB NWPTR eventControlBlock,
                                 WORD functionNumber);

   extern void NWAPI IPXRelinquishControl(void);

   extern void NWAPI IPXScheduleIPXEvent(WORD timeUnits,
                                         ECB NWPTR eventControlBlock);

   /* internal procedure */
   extern void NWAPI IPXScheduleSpecialEvent(WORD timeUnits,
                                             ECB NWPTR eventControlBlock);

   extern void NWAPI IPXSendPacket(ECB NWPTR eventControlBlock);

   extern void NWAPI SPXAbortConnection(WORD connectionID);

   extern int  NWAPI SPXEstablishConnection(BYTE retryCount,
                                            BYTE watchDog,
                                            WORD NWPTR  connectionID, 
                                            ECB NWPTR eventControlBlock);

   extern int  NWAPI SPXGetConnectionStatus(WORD connectionID,
                                            CONNECTION_INFO NWPTR connectionInfo);

   extern int  NWAPI SPXInitialize(BYTE NWPTR majorRevisionNumber,
                                   BYTE NWPTR minorRevisionNumber, 
                                   WORD NWPTR maxConnections,
                                   WORD NWPTR availableConnection);

   extern void NWAPI SPXListenForConnection(BYTE retryCount,
                                            BYTE watchDog,
                                            ECB NWPTR eventControlBlock);

   extern void NWAPI SPXListenForSequencedPacket(ECB NWPTR eventControlBlock);

   /* internal procedure */
   extern int  NWAPI _SPXrequest(WORD connectionID,
                                 ECB NWPTR eventControlBlock,
                                 WORD functionNumber);

   extern void NWAPI SPXSendSequencedPacket(WORD connectionID,
                                            ECB NWPTR eventControlBlock);

   extern void NWAPI SPXTerminateConnection(WORD connectionID,
                                            ECB NWPTR eventControlBlock);

#ifdef __cplusplus
   }
#endif /* __cplusplus */

#endif /* _NXT_H */
