/*****************************************************************************
 *
 * Program Name:  SPX for OS/2
 *
 * Filename:	  spxcalls.h
 *
 * Date Created:  August 8, 1991
 *
 * Version:		  2.0
 *
 * (C) Unpublished Copyright of Novell, Inc.  All Rights Reserved.
 *
 * No part of this file may be duplicated, revised, translated, localized,
 * or modified in any manner or compiled, linked or uploaded or downloaded
 * to or from any computer system without the prior written consent of
 * Novell, Inc.
 *
 ****************************************************************************/

#if !defined (SPXCALLS_INCLUDED)

/*-------------------------------------------------------------------------
 * Constants.
 */
#define SPXCALLS_INCLUDED

#ifndef NWCALDEF_INC
#include <nwcaldef.h>
#endif

/* SPX_ECB component error check flags */
#define	ECB_ERROR_CHECK_OFF	0x0000
#define	ECB_ERROR_CHECK_ON	0x0001


/* SPX Connection flags */
#define WATCHDOG_CONNECTION	0x02

/*-------------------------------------------------------------------------
 * SPX Type definitions.
 */
typedef struct
{
	VOID NWPTR fragAddress;
	USHORT		fragSize;				/* lo-hi */
} SPXECBFrag;


typedef struct SPX_ECBStruct
{
	struct SPX_ECBStruct NWPTR next;
	struct SPX_ECBStruct NWPTR prev;
	USHORT						status;
	ULONG					   	reserved;
	USHORT					   	lProtID;
	UCHAR					   	protID[6];
	USHORT					   	boardNumber;
	UCHAR					   	immediateAddress[6];
	UCHAR					   	driverWS[4];
	void NWPTR 				   	hsem;
	UCHAR					   	protocolWS[4];
	USHORT					   	dataLen;
	USHORT					   	fragCount;
	SPXECBFrag	 			   	fragList[2];

} SPX_ECB;


typedef struct
{
	USHORT		checksum;			/* hi-lo */
	USHORT		packetLen;			/* hi-lo */
	UCHAR		transportCtl;
	UCHAR		packetType;
	ULONG		destNet;			/* hi-lo */
	UCHAR		destNode[6];		/* hi-lo */
	USHORT		destSocket;			/* hi-lo */
	ULONG		sourceNet;			/* hi-lo */
	UCHAR		sourceNode[6];		/* hi-lo */
	USHORT		sourceSocket;		/* hi-lo */

	UCHAR		connectionCtl;
	UCHAR		dataStreamType;
	USHORT		sourceConnectID;	/* hi-lo */
	USHORT		destConnectID;		/* hi-lo */
	USHORT		sequenceNumber;		/* hi-lo */
	USHORT		ackNumber;			/* hi-lo */
	USHORT		allocNumber;		/* hi-lo */

} SPX_HEADER;


typedef struct SPX_ConnStruct
{
	UCHAR		sStatus;
	UCHAR		sFlags;

	USHORT		sSourceConnectID;			/* lo-hi */
	USHORT		sDestConnectID;				/* lo-hi */
	USHORT		sSequenceNumber;			/* lo-hi */
	USHORT		sAckNumber;					/* lo-hi */
	USHORT		sAllocNumber;				/* lo-hi */

	USHORT		sRemoteSequenceNumber;		/* lo-hi */
	USHORT		sRemoteAckNumber;			/* lo-hi */
	USHORT		sRemoteAllocNumber;			/* lo-hi */

	USHORT		sLProtID;					/* lo-hi */
	UCHAR		sProtID[6];					/* hi-lo */
	USHORT		sBoardNumber;				/* lo-hi */
	UCHAR		sImmediateAddress[6];		/* hi-lo */

	ULONG		sRemoteNet;					/* hi-lo */
	UCHAR		sRemoteNode[6];				/* hi-lo */
	USHORT		sRemoteSocket;				/* hi-lo */

	USHORT		sRetryCount;				/* lo-hi */
	ULONG		sRoundTripTimer;			/* lo-hi */
	USHORT		sRetransmitCount;			/* lo-hi */


} SPX_SESSION;

/*-------------------------------------------------------------------------
 *	SPX function prototypes.
 */
extern USHORT NWAPI SpxAbortConnection(
		USHORT	connection );

extern USHORT NWAPI SpxCancelPacket(
		SPX_ECB NWPTR ecb );

extern USHORT NWAPI SpxCheckSocket(
		USHORT	socket );

extern USHORT NWAPI SpxCloseSocket(
		USHORT	socket );

extern USHORT NWAPI SpxECBErrorCheck(
		USHORT		checkFlag );

extern USHORT NWAPI SpxEstablishConnection(
		USHORT		socket,
		SPX_ECB NWPTR ecb,
		UCHAR		retryCount,
		UCHAR		flags,
		USHORT NWPTR connection );

extern USHORT NWAPI SpxEstablishConnection2(
		USHORT		socket,
		SPX_ECB NWPTR connectEcb,
		SPX_ECB NWPTR listenEcb,
		UCHAR		retryCount,
		UCHAR		flags,
		USHORT NWPTR connection );

extern USHORT NWAPI	SpxGetConfiguration(
		USHORT NWPTR maximumConnections,
		USHORT NWPTR availableConnections);

extern USHORT NWAPI SpxGetConnectionStatus(
		USHORT				connection,
		SPX_SESSION NWPTR sessionBuffer );

extern USHORT NWAPI SpxGetVersion(
		UCHAR NWPTR major,
		UCHAR NWPTR minor,
		UCHAR NWPTR revision );

extern USHORT NWAPI SpxListenForConnection(
		USHORT		socket,
		SPX_ECB NWPTR ecb,
		UCHAR		retryCount,
		UCHAR		flags,
		USHORT NWPTR connection );

extern USHORT NWAPI SpxListenForConnection2(
		USHORT		socket,
		SPX_ECB NWPTR connectEcb,
		SPX_ECB NWPTR listenEcb,
		UCHAR		retryCount,
		UCHAR		flags,
		USHORT NWPTR connection );

extern USHORT NWAPI SpxListenForConnectionPacket(
		USHORT			usConnection,
		SPX_ECB NWPTR ecb );

extern USHORT NWAPI SpxNPNotifyAbort(
		USHORT 		usConnection);

extern USHORT NWAPI SpxOpenSocket(
		USHORT NWPTR socket );

extern USHORT NWAPI SpxSendSequencedPacket(
		USHORT		connection,
		SPX_ECB NWPTR ecb );

extern USHORT NWAPI SpxTerminateConnection(
		USHORT		connection,
		SPX_ECB NWPTR ecb );

#endif	/* SPXCALLS_INCLUDED */

/*=========================================================================*/







